@@ -13,12 +13,14 @@ class VRFPrimaryVLAN(PrimaryModel):
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="vrfprimaryvlan",
     )
     vrf = models.OneToOneField(
         VRF,
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="vrfprimaryvlan",
     )
 
     class Meta:
@@ -49,17 +51,19 @@ class EthernetSegment(PrimaryModel):
         return "{} ({})".format(self.name, self.segment_id)
 
     def get_absolute_url(self):
-        return reverse("plugins:nautobot_evpn:es", args=[self.pk])
+        return reverse("plugins:nautobot_evpn:ethernetsegment", args=[self.pk])
 
 
 class EthernetSegmentMembership(PrimaryModel):
     segment = models.ForeignKey(
         EthernetSegment,
-        on_delete=models.CASCADE
+        on_delete=models.CASCADE,
+        related_name="ethernet_segment_memberships"
     )
     interface = models.OneToOneField(
         Interface,
-        on_delete=models.CASCADE
+        on_delete=models.CASCADE,
+        related_name="ethernet_segment_membership"
     )
 
     csv_headers = ["segment", "interface"]
@@ -80,12 +84,14 @@ class VLANVRFList(PrimaryModel):
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="vlanvrflist",
     )
     vrf = models.ForeignKey(
         VRF,
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="vlanvrflist",
     )
 
     class Meta:
@@ -102,12 +108,14 @@ class AnycastIP(PrimaryModel):
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="anycastip",
     )
     ip = models.OneToOneField(
         IPAddress,
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="anycastip",
     )
 
     def __str__(self):
@@ -120,12 +128,14 @@ class AnycastDummyIP(PrimaryModel):
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="anycastdummyip",
     )
     ip = models.OneToOneField(
         IPAddress,
         blank=False,
         null=False,
         on_delete=models.CASCADE,
+        related_name="anycastdummyip",
     )
 
     def __str__(self):
